services — Translate Toolkit 2.4.0 documentation

# services

translate.services is part of the translate toolkit. It provides network services for interacting with the toolkit

## tmserver

A translation memory server using tmdb for storage, communicates with clients using JSON over HTTP.

class `translate.services.tmserver.` `TMServer`(tmdbfile, tmfiles, max_candidates=3, min_similarity=75, max_length=1000, prefix='', source_lang=None, target_lang=None)

  A RESTful JSON TM server.